
/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mappings are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package org.objectweb.jorm.facility.naming.generator;

import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.naming.api.PExceptionNaming;
import org.objectweb.jorm.naming.api.PName;
import org.objectweb.jorm.naming.api.PNameCoder;
import org.objectweb.jorm.naming.api.PNameGetter;
import org.objectweb.jorm.naming.lib.AbstractInheritPNamingContext;


public class LongGenIncrFPNC extends AbstractInheritPNamingContext {

	public LongGenIncrFPNC() {
		//The naming is not composite, then we use a PNGConverter
		super(PNameCoder.CTSTRING, new org.objectweb.jorm.naming.lib.SimplePNGConverter());
	}

	private PName decode(PNameGetter png) throws PExceptionNaming {
		//use the PNameGetter to build a PName
		PName pn = new org.objectweb.jorm.facility.naming.basidir.BasidName(png, this, PNameCoder.CTSTRING);

		// resolve the PName
		try {
			return resolve(null, pn);
		} catch (PException e) {
			throw new PExceptionNaming(e, "Impossible to resolve " + png);
		}
	}

	// DECODE METHODS IMPLEMENTATION //
	//------------------------------//

	public PName decodeAbstract(Object o, Object hints) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			if (o instanceof PNameGetter) {
				png = (PNameGetter) o;
			} else {
				throw new PExceptionNaming("Impossible to decode " + o);
			}
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}

	public PName decodeByte(byte o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeChar(char o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeDate(java.util.Date o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeInt(int o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeLong(long o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeObyte(java.lang.Byte o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeOchar(java.lang.Character o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeOint(java.lang.Integer o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeOlong(java.lang.Long o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeOshort(java.lang.Short o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeShort(short o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeString(java.lang.String o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decode(byte[] o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeCharArray(char[] o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeBigDecimal(java.math.BigDecimal o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}
	public PName decodeBigInteger(java.math.BigInteger o) throws PExceptionNaming {
		//convert 'o' to a PNameGetter
		PNameGetter png;
		if (converter == null) {
			throw new PExceptionNaming("Impossible to decode " + o);
		} else {
			png = converter.convert(o);
		}
		return decode(png);
	}

	// MATCH METHODS IMPLEMENTATION //
	//------------------------------//

	public boolean match(Object en) {
		if (en instanceof PNameGetter) {
			return true;
		} else {
			return false;
		}
	}
	public boolean match(byte o) {
		return false;
	}
	public boolean match(char o) {
		return false;
	}
	public boolean match(java.util.Date o) {
		return false;
	}
	public boolean match(int o) {
		return false;
	}
	public boolean match(long o) {
		return false;
	}
	public boolean match(java.lang.Byte o) {
		return false;
	}
	public boolean match(java.lang.Character o) {
		return false;
	}
	public boolean match(java.lang.Integer o) {
		return false;
	}
	public boolean match(java.lang.Long o) {
		return false;
	}
	public boolean match(java.lang.Short o) {
		return false;
	}
	public boolean match(short o) {
		return false;
	}
	public boolean match(java.lang.String o) {
		return false;
	}
	public boolean match(byte[] o) {
		return false;
	}
	public boolean match(char[] o) {
		return false;
	}
	public boolean match(java.math.BigDecimal o) {
		return false;
	}
	public boolean match(java.math.BigInteger o) {
		return false;
	}
}