/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mappings are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2003 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */

package org.objectweb.jorm.facility.naming.generator;

import org.objectweb.jorm.naming.api.PBinder;
import org.objectweb.jorm.naming.api.PExceptionNaming;
import org.objectweb.jorm.api.PExceptionProtocol;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.naming.api.PName;
import org.objectweb.jorm.naming.api.PNameCoder;
import org.objectweb.jorm.api.PSerializable;
import org.objectweb.jorm.api.PAccessor;
import org.objectweb.jorm.api.PAccessorGen;
import org.objectweb.jorm.api.PClassMapping;

public class LongGenIncrSerializable implements PSerializable, LongGenIncrAccessor {

	//the pname of the object
	protected String pName;
	
		protected long nextId;
	
	public String setPName(PName pName){
		if(pName.codingSupported((short) PNameCoder.CTSTRING)){
			try{
				this.pName  = pName.encodeString();
			}
			catch(Exception e){
			}
		}
		else{
			this.pName = "null";
		}
		return this.pName;
	}
	
	public PName getPName(PBinder pnc) throws PExceptionNaming{
		try{
			return pnc.decodeString(pName);
		}catch (Exception e) {
              throw new PExceptionNaming("Cannot decode to a PName: " + e.getMessage());
        }
	}
	
	public String getClassName(){
		return "org.objectweb.jorm.facility.naming.generator.LongGenIncr";
	}
	

	public void paSetNextId(long val){
		nextId = val;
	}
	public long paGetNextId() {
		return nextId;
	}

	public Object getMemoryInstance(){
		return this;
	}
	
	
	public String toString(){
		StringBuffer s = new StringBuffer();
		s.append("data(");
					s.append(nextId + ",  ");
				s.append(pName + ")");
		return s.toString();
	}
	
	
	public void read(PClassMapping pcm, PAccessor pa) throws PException{
		LongGenIncrAccessor paccessor = null;
		PAccessorGen paccessorGen = null;
		if (pa == null)
			throw new PException("Accessor must not be null");
		else if (pa instanceof LongGenIncrAccessor)
			paccessor = (LongGenIncrAccessor) pa;
		else if (pa instanceof PAccessorGen)
			paccessorGen = (PAccessorGen) pa;
		else
			throw new PException("Wrong type of accessor: " + pa);
	 	try {	
			if(paccessor != null){
											paccessor.paSetNextId(paGetNextId());
							 			}
 			else{
	  		 			        		//paccessorGen.paSetLongField("nextId", paGetNextId(pcm), null);
	        			        	 }  
		}
 		catch (PException pe) {
			throw pe;
		} catch (Exception e) {
			throw new PException(e.toString());
		} 
	}
	
	public void write(PClassMapping pcm, PAccessor pa) throws PException{
		LongGenIncrAccessor paccessor = null;
		PAccessorGen paccessorGen = null;
		if (pa == null)
			throw new PExceptionProtocol("Accessor must not be null");
		else if (pa instanceof LongGenIncrAccessor)
			paccessor = (LongGenIncrAccessor) pa;
		else if (pa instanceof PAccessorGen)
			paccessorGen = (PAccessorGen) pa;
		else
			throw new PExceptionProtocol("Wrong type of accessor: " + pa);
		try {	
			if(paccessor != null){
											paSetNextId(paccessor.paGetNextId());
							 			}
 			else{
	  		 				        	//	paSetLongField(nextId, paccessorGen.paGetNextId());
        		//paSetLongField("nextId", paccessorGen.paGetLongField("nextId"));
        		//paSetNextId(paccessorGen.paGetLongField("nextId"), null);
	        			        	 }  
		}
 		catch (PException pe) {
			throw pe;
		} catch (Exception e) {
			throw new PException(e.toString());
		} 
	}
}